@@ -36,7 +36,7 @@ void AsyncHTTPLookupTest::testLookup()
   client_->config().setFreedbLookupTransport(Lookup::HTTP);
   client_->setBlockingMode( false );
 
-  connect(client_, SIGNAL(finished(KCDDB::Result)), SLOT(slotFinished(KCDDB::Result)));
+  connect(client_, &KCDDB::Client::finished, this, &AsyncHTTPLookupTest::slotFinished);
 
   TrackOffsetList list;
 
